;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "tempel" "20251115.1817"
  "Tempo templates/snippets with in-buffer field editing."
  '((emacs  "29.1")
    (compat "30"))
  :url "https://github.com/minad/tempel"
  :commit "56b6e6e3e95054876cfb96b1f3a460824baec8c6"
  :revdesc "56b6e6e3e950"
  :keywords '("abbrev" "languages" "tools" "text")
  :authors '(("Daniel Mendler" . "mail@daniel-mendler.de"))
  :maintainers '(("Daniel Mendler" . "mail@daniel-mendler.de")))
